@@ -23,6 +23,7 @@ class Runner(object):
         self.image_id = project.image_id
         self.dns = project.docker_dns
         self.docker_config = kwargs
+        self.last_container = None
 
     def run(self, command):
         volumes = {'/sb': {}, Runner.WORKING_DIR: {}}
@@ -52,8 +53,8 @@ class Runner(object):
             else:
                 raise
         self.client.start(container=cont, binds=binds)
-
-        return Container(self.client, self.project, cont)
+        self.last_container = Container(self.client, self.project, cont)
+        return self.last_container
 
     def run_and_print(self, command, remove=False):
         cont = self.run(command)
@@ -63,8 +64,9 @@ class Runner(object):
             cont.stop()
 
         with handle_signal(handler, signal.SIGTERM, signal.SIGINT):
-            cont.print_log()  # TODO: non-blocking io
-        cont.wait()
+            cont.wait()
+
+        cont.print_log()
         if remove:
             cont.remove()
 
