@@ -39,8 +39,8 @@ def main(argv=None, context=None):
     underscored = dict([(k.replace('-', '_'), v) for k, v in args.items()])
     try:
         f(project, **underscored)
-    except SbdkError, e:
-        print e.message
+    except SbdkError as e:
+        print(e.message)
         sys.exit(1)
 
 
